@@ -1,10 +1,9 @@
-import os
 try:
     import torch
 except ImportError:
-    raise ImportError # Torch is not installed. Please install through https://pytorch.org/get-started/locally/
+    raise ImportError('Torch is not installed. Please install through https://pytorch.org/get-started/locally/')
 from .data import DataProcess
-from .train import Trainer
+from .losses import *
 from .predict import Predict
 from .siam_unet import Siam_UNet
-from .losses import *
\ No newline at end of file
+from .train import Trainer
