@@ -1,8 +1,9 @@
 from torch import nn
 import torch
 
+
 class Siam_UNet(nn.Module):
-    def __init__(self, n_filter=64, bias=0):
+    def __init__(self, n_filter=32):
         super().__init__()
         # encode
         self.encode1 = self.conv(1, n_filter)
@@ -52,8 +53,6 @@ class Siam_UNet(nn.Module):
         self.decode9 = self.conv(1 * n_filter, 1)
         self.final = nn.Sequential(
             nn.Conv2d(1, 1, kernel_size=1, padding=0),
-            AddBias(bias=bias),
-            nn.Sigmoid(),
         )
 
     def conv(self, in_channels, out_channels, kernel_size=3, dropout=0.0):
@@ -125,16 +124,5 @@ class Siam_UNet(nn.Module):
         d7 = self.decode7(c4)
         d8 = self.decode8(d7)
         d9 = self.decode9(d8)
-        out = self.final(d9)
-        return out
-
-class AddBias(nn.Module):
-    """Add scalar to tensor"""
-
-    def __init__(self, bias=0):
-        super(AddBias, self).__init__()
-        self.bias = bias
-
-    def forward(self, input):
-        return torch.add(input, self.bias)
-
+        logits = self.final(d9)
+        return torch.sigmoid(logits), logits
